#
#TODO(bogdando) sync extended qpid rpc backend configuration here as well
# [use_stderr] Rather or not service should send output to stderr. Optional. Defaults to true.
#

class openstack::heat (
  $external_ip                   = '127.0.0.1',
  $enabled                       = true,

  $keystone_auth                 = true,
  $keystone_host                 = '127.0.0.1',
  $keystone_port                 = '35357',
  $keystone_service_port         = '5000',
  $keystone_protocol             = 'http',
  $public_ssl                    = false,
  $keystone_user                 = 'heat',
  $keystone_tenant               = 'services',
  $keystone_password             = false,
  $keystone_ec2_uri              = false,
  $region                        = 'RegionOne',
  $auth_uri                      = false,
  $trusts_delegated_roles        = [],

  $verbose                       = false,
  $debug                         = false,
  $use_syslog                    = false,
  $use_stderr                    = true,
  $syslog_log_facility           = 'LOG_LOCAL0',
  $log_dir                       = '/var/log/heat',

  $rpc_backend                   = 'heat.openstack.common.rpc.impl_kombu',
  $amqp_hosts                    = ['127.0.0.1:5672'],
  $amqp_user                     = 'heat',
  $amqp_password                 = false,
  $rabbit_virtualhost            = '/',

  $heat_stack_user_role          = 'heat_stack_user',
  $heat_metadata_server_url      = false,
  $heat_waitcondition_server_url = false,
  $heat_watch_server_url         = false,
  $auth_encryption_key           = '%ENCRYPTION_KEY%',

  $sql_connection                = false,
  $db_user                       = 'heat',
  $db_password                   = false,
  $db_host                       = '127.0.0.1',
  $db_name                       = 'heat',
  $db_allowed_hosts              = ['localhost','%'],
  $idle_timeout                  = '3600',
  $max_pool_size                 = '10',
  $max_overflow                  = '30',
  $max_retries                   = '-1',

  $ic_https_validate_certs       = '1',
  $ic_is_secure                  = '0',

  $api_bind_host                 = '0.0.0.0',
  $api_bind_port                 = '8004',
  $api_cfn_bind_host             = '0.0.0.0',
  $api_cfn_bind_port             = '8000',
  $api_cloudwatch_bind_host      = '0.0.0.0',
  $api_cloudwatch_bind_port      = '8003',
){

  # No empty passwords allowed
  validate_string($amqp_password)

  # Generate values logic
  if $keystone_ec2_uri {
    $keystone_ec2_uri_real    = $keystone_ec2_uri
  } else {
    $keystone_ec2_uri_real    = "${keystone_protocol}://${keystone_host}:${keystone_port}/v2.0/ec2tokens"
  }
  if $heat_metadata_server_url {
    $metadata_server_url      = $heat_metadata_server_url
  } else {
    $metadata_server_url      = "http://${external_ip}:${api_cfn_bind_port}"
  }
  if $heat_waitcondition_server_url {
    $waitcondition_server_url = $heat_waitcondition_server_url
  } else {
    $waitcondition_server_url = "http://${external_ip}:${api_cfn_bind_port}/v1/waitcondition"
  }
  if $heat_watch_server_url {
    $watch_server_url         = $heat_watch_server_url
  } else {
    $watch_server_url         = "http://${external_ip}:${api_cloudwatch_bind_port}"
  }

  # TODO(bogdando) clarify this config section (left from upstream presync state)
  heat_config {
    'DEFAULT/instance_connection_https_validate_certificates' : value => $ic_https_validate_certs;
    'DEFAULT/instance_connection_is_secure'                   : value => $ic_is_secure;
  }
  Package<| title == 'heat-api-cfn' or title == 'heat-api-cloudwatch' |>
  Heat_config <|
    title == 'DEFAULT/instance_connection_https_validate_certificates' or
    title == 'DEFAULT/instance_connection_is_secure'
  |> ->
  Service<| title == 'heat-api-cfn' or title == 'heat-api-cloudwatch' |>

  # Syslog configuration
  if $use_syslog {
    heat_config {
      'DEFAULT/use_syslog_rfc_format': value => true;
    }
  }

  # Firewall rules for APIs
  firewall { '206 heat-api-cloudwatch' :
    dport  => [ $api_cloudwatch_bind_port ],
    proto  => 'tcp',
    action => 'accept',
  } ->
  firewall { '205 heat-api-cfn' :
    dport  => [ $api_cfn_bind_port ],
    proto  => 'tcp',
    action => 'accept',
  } ->
  firewall { '204 heat-api' :
    dport  => [ $api_bind_port ],
    proto  => 'tcp',
    action => 'accept',
  }

  # Common configuration, logging and RPC
  class { '::heat':
    auth_uri              => $auth_uri,
    keystone_ec2_uri      => $keystone_ec2_uri_real,
    keystone_host         => $keystone_host,
    keystone_port         => $keystone_port,
    keystone_protocol     => $keystone_protocol,
    keystone_user         => $keystone_user,
    keystone_tenant       => $keystone_tenant,
    keystone_password     => $keystone_password,
    region_name           => $region,

    sql_connection        => $sql_connection,
    database_idle_timeout => $idle_timeout,

    rpc_backend           => $rpc_backend,
    rabbit_hosts          => $amqp_hosts,
    rabbit_userid         => $amqp_user,
    rabbit_password       => $amqp_password,
    rabbit_virtual_host   => $rabbit_virtualhost,

    log_dir               => $log_dir,
    verbose               => $verbose,
    debug                 => $debug,
    use_syslog            => $use_syslog,
    use_stderr            => $use_stderr,
    log_facility          => $syslog_log_facility,
  }

  heat_config {
    'DEFAULT/max_template_size':       value => '5440000';
    'DEFAULT/max_json_body_size':      value => '10880000';
    'DEFAULT/max_resources_per_stack': value => '20000';
    'DEFAULT/rpc_response_timeout':    value => '600';
  }

  heat_config {
    'DEFAULT/notification_driver': value => 'heat.openstack.common.notifier.rpc_notifier';
    'DATABASE/max_pool_size':      value => $max_pool_size;
    'DATABASE/max_overflow':       value => $max_overflow;
    'DATABASE/max_retries':        value => $max_retries;
  }

  # Engine
  class { 'heat::engine' :
    auth_encryption_key           => $auth_encryption_key,
    heat_stack_user_role          => $heat_stack_user_role,
    heat_metadata_server_url      => $metadata_server_url,
    heat_waitcondition_server_url => $waitcondition_server_url,
    heat_watch_server_url         => $watch_server_url,
    trusts_delegated_roles        => $trusts_delegated_roles,
  }

  # Install the heat APIs
  class { 'heat::api':
    bind_host => $api_bind_host,
    bind_port => $api_bind_port,
    enabled   => $enabled,
  }
  class { 'heat::api_cfn' :
    bind_host => $api_cfn_bind_host,
    bind_port => $api_cfn_bind_port,
    enabled   => $enabled,
  }
  class { 'heat::api_cloudwatch' :
    bind_host => $api_cloudwatch_bind_host,
    bind_port => $api_cloudwatch_bind_port,
    enabled   => $enabled,
  }

  # Client
  class { 'heat::client' :  }
}
