#!/usr/bin/env python
#
#    Copyright 2015 Mirantis, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
#
# This script accepts a json dump via stdin that was generated by calling the
# rabbitmq /api/definitions endpoint. It then removes the queues, bindings and
# exchanges that should not be restored if the dump was loaded and prints
# the json back out to stdout.
#

import json
import re
import sys

defs = json.loads(sys.stdin.read())

regexp = re.compile(r'^.*[0-9a-f]{8}(?:-[0-9a-f]{4}){3}-[0-9a-f]{12}$', re.I)

defs['queues'] = [x for x in defs['queues']
                  if not (x['auto_delete'] or re.match(regexp, x['name']))]

queues = set([n['name'] for n in defs['queues']])
defs['bindings'] = [x for x in defs['bindings'] if x['destination']
                    in queues]

sources = set([n['source'] for n in defs['bindings']])
defs['exchanges'] = [x for x in defs['exchanges'] if x['name']
                     in sources]

print (json.dumps(defs))
